@@ -37,12 +37,17 @@
 #define _RADEON_PROBE_H_ 1
 
 #include <stdint.h>
+#include "xorg-server.h"
 #include "xf86str.h"
 #include "xf86DDC.h"
 #include "randrstr.h"
 
 #include "xf86Crtc.h"
 
+#ifdef XSERVER_PLATFORM_BUS
+#include "xf86platformBus.h"
+#endif
+
 #include "compat-api.h"
 #include "exa.h"
 
@@ -110,6 +115,8 @@ typedef enum {
     CHIP_FAMILY_BONAIRE,
     CHIP_FAMILY_KAVERI,
     CHIP_FAMILY_KABINI,
+    CHIP_FAMILY_HAWAII,
+    CHIP_FAMILY_MULLINS,
     CHIP_FAMILY_LAST
 } RADEONChipFamily;
 
@@ -125,17 +132,20 @@ typedef struct {
 
 typedef struct
 {
-    Bool HasSecondary;
     Bool              HasCRTC2;         /* All cards except original Radeon  */
-
-    ScrnInfoPtr pSecondaryScrn;    
-    ScrnInfoPtr pPrimaryScrn;
+    Bool has_page_flip_target;
 
     int fd;                             /* for sharing across zaphod heads   */
     int fd_ref;
     unsigned long     fd_wakeup_registered; /* server generation for which fd has been registered for wakeup handling */
     int fd_wakeup_ref;
-    int dri2_info_cnt;
+    unsigned int assigned_crtcs;
+    ScrnInfoPtr primary_scrn;
+    ScrnInfoPtr secondary_scrn;
+#ifdef XSERVER_PLATFORM_BUS
+    struct xf86_platform_device *platform_dev;
+#endif
+    char *render_node;
 } RADEONEntRec, *RADEONEntPtr;
 
 extern const OptionInfoRec *RADEONOptionsWeak(void);
